@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: bandwidth.h 13625 2012-12-05 17:29:46Z jordan $
+ * $Id: bandwidth.h 13936 2013-02-02 20:17:52Z jordan $
  */
 
 #ifndef __TRANSMISSION__
@@ -34,33 +34,33 @@ struct tr_peerIo;
  * it's included in the header for inlining and composition. */
 enum
 {
-    HISTORY_MSEC = 2000u,
-    INTERVAL_MSEC = HISTORY_MSEC,
-    GRANULARITY_MSEC = 200,
-    HISTORY_SIZE = (INTERVAL_MSEC / GRANULARITY_MSEC),
-    BANDWIDTH_MAGIC_NUMBER = 43143
+  HISTORY_MSEC = 2000u,
+  INTERVAL_MSEC = HISTORY_MSEC,
+  GRANULARITY_MSEC = 200,
+  HISTORY_SIZE = (INTERVAL_MSEC / GRANULARITY_MSEC),
+  BANDWIDTH_MAGIC_NUMBER = 43143
 };
 
 /* these are PRIVATE IMPLEMENTATION details that should not be touched.
  * it's included in the header for inlining and composition. */
 struct bratecontrol
 {
-    int newest;
-    struct { uint64_t date, size; } transfers[HISTORY_SIZE];
-    uint64_t cache_time;
-    unsigned int cache_val;
+  int newest;
+  struct { uint64_t date, size; } transfers[HISTORY_SIZE];
+  uint64_t cache_time;
+  unsigned int cache_val;
 };
 
 /* these are PRIVATE IMPLEMENTATION details that should not be touched.
  * it's included in the header for inlining and composition. */
 struct tr_band
 {
-    bool isLimited;
-    bool honorParentLimits;
-    unsigned int bytesLeft;
-    unsigned int desiredSpeed_Bps;
-    struct bratecontrol raw;
-    struct bratecontrol piece;
+  bool isLimited;
+  bool honorParentLimits;
+  unsigned int bytesLeft;
+  unsigned int desiredSpeed_Bps;
+  struct bratecontrol raw;
+  struct bratecontrol piece;
 };
 
 /**
@@ -104,17 +104,17 @@ struct tr_band
  */
 typedef struct tr_bandwidth
 {
-    /* these are PRIVATE IMPLEMENTATION details that should not be touched.
-     * it's included in the header for inlining and composition. */
+  /* these are PRIVATE IMPLEMENTATION details that should not be touched.
+   * it's included in the header for inlining and composition. */
 
-    struct tr_band band[2];
-    struct tr_bandwidth * parent;
-    tr_priority_t priority;
-    int magicNumber;
-    unsigned int uniqueKey;
-    tr_session * session;
-    tr_ptrArray children; /* struct tr_bandwidth */
-    struct tr_peerIo * peer;
+  struct tr_band band[2];
+  struct tr_bandwidth * parent;
+  tr_priority_t priority;
+  int magicNumber;
+  unsigned int uniqueKey;
+  tr_session * session;
+  tr_ptrArray children; /* struct tr_bandwidth */
+  struct tr_peerIo * peer;
 }
 tr_bandwidth;
 
@@ -130,9 +130,10 @@ void tr_bandwidthConstruct (tr_bandwidth * bandwidth,
 void tr_bandwidthDestruct (tr_bandwidth * bandwidth);
 
 /** @brief test to see if the pointer refers to a live bandwidth object */
-static inline bool tr_isBandwidth (const tr_bandwidth  * b)
+static inline bool
+tr_isBandwidth (const tr_bandwidth  * b)
 {
-    return (b != NULL) && (b->magicNumber == BANDWIDTH_MAGIC_NUMBER);
+  return (b != NULL) && (b->magicNumber == BANDWIDTH_MAGIC_NUMBER);
 }
 
 /******
@@ -144,14 +145,15 @@ static inline bool tr_isBandwidth (const tr_bandwidth  * b)
  * @see tr_bandwidthAllocate
  * @see tr_bandwidthGetDesiredSpeed
  */
-static inline bool tr_bandwidthSetDesiredSpeed_Bps (tr_bandwidth        * bandwidth,
-                                                    tr_direction          dir,
-                                                    unsigned int          desiredSpeed)
+static inline bool
+tr_bandwidthSetDesiredSpeed_Bps (tr_bandwidth  * bandwidth,
+                                 tr_direction    dir,
+                                 unsigned int    desiredSpeed)
 {
-    unsigned int * value = &bandwidth->band[dir].desiredSpeed_Bps;
-    const bool didChange = desiredSpeed != *value;
-    *value = desiredSpeed;
-    return didChange;
+  unsigned int * value = &bandwidth->band[dir].desiredSpeed_Bps;
+  const bool didChange = desiredSpeed != *value;
+  *value = desiredSpeed;
+  return didChange;
 }
 
 /**
@@ -161,44 +163,46 @@ static inline bool tr_bandwidthSetDesiredSpeed_Bps (tr_bandwidth        * bandwi
 static inline double
 tr_bandwidthGetDesiredSpeed_Bps (const tr_bandwidth  * bandwidth, tr_direction dir)
 {
-    return bandwidth->band[dir].desiredSpeed_Bps;
+  return bandwidth->band[dir].desiredSpeed_Bps;
 }
 
 /**
  * @brief Set whether or not this bandwidth should throttle its peer-io's speeds
  */
-static inline bool tr_bandwidthSetLimited (tr_bandwidth  * bandwidth,
-                                           tr_direction    dir,
-                                           bool            isLimited)
+static inline bool
+tr_bandwidthSetLimited (tr_bandwidth  * bandwidth,
+                        tr_direction    dir,
+                        bool            isLimited)
 {
-    bool * value = &bandwidth->band[dir].isLimited;
-    const bool didChange = isLimited != *value;
-    *value = isLimited;
-    return didChange;
+  bool * value = &bandwidth->band[dir].isLimited;
+  const bool didChange = isLimited != *value;
+  *value = isLimited;
+  return didChange;
 }
 
 /**
  * @return nonzero if this bandwidth throttles its peer-ios speeds
  */
-static inline bool tr_bandwidthIsLimited (const tr_bandwidth  * bandwidth,
-                                          tr_direction          dir)
+static inline bool
+tr_bandwidthIsLimited (const tr_bandwidth  * bandwidth,
+                       tr_direction          dir)
 {
-    return bandwidth->band[dir].isLimited;
+  return bandwidth->band[dir].isLimited;
 }
 
 /**
  * @brief allocate the next period_msec's worth of bandwidth for the peer-ios to consume
  */
-void    tr_bandwidthAllocate        (tr_bandwidth        * bandwidth,
-                                        tr_direction          direction,
-                                        unsigned int          period_msec);
+void tr_bandwidthAllocate (tr_bandwidth  * bandwidth,
+                           tr_direction    direction,
+                           unsigned int    period_msec);
 
 /**
  * @brief clamps byteCount down to a number that this bandwidth will allow to be consumed
  */
-unsigned int  tr_bandwidthClamp     (const tr_bandwidth  * bandwidth,
-                                        tr_direction          direction,
-                                        unsigned int          byteCount);
+unsigned int tr_bandwidthClamp (const tr_bandwidth  * bandwidth,
+                                tr_direction          direction,
+                                unsigned int          byteCount);
 
 /******
 *******
@@ -206,8 +210,8 @@ unsigned int  tr_bandwidthClamp     (const tr_bandwidth  * bandwidth,
 
 /** @brief Get the raw total of bytes read or sent by this bandwidth subtree. */
 unsigned int tr_bandwidthGetRawSpeed_Bps (const tr_bandwidth  * bandwidth,
-                                           const uint64_t        now,
-                                           const tr_direction    direction);
+                                          const uint64_t        now,
+                                          const tr_direction    direction);
 
 /** @brief Get the number of piece data bytes read or sent by this bandwidth subtree. */
 unsigned int tr_bandwidthGetPieceSpeed_Bps (const tr_bandwidth  * bandwidth,
@@ -218,18 +222,18 @@ unsigned int tr_bandwidthGetPieceSpeed_Bps (const tr_bandwidth  * bandwidth,
  * @brief Notify the bandwidth object that some of its allocated bandwidth has been consumed.
  * This is is usually invoked by the peer-io after a read or write.
  */
-void    tr_bandwidthUsed            (tr_bandwidth        * bandwidth,
-                                        tr_direction          direction,
-                                        size_t                byteCount,
-                                        bool                  isPieceData,
-                                        uint64_t              now);
+void tr_bandwidthUsed (tr_bandwidth  * bandwidth,
+                       tr_direction    direction,
+                       size_t          byteCount,
+                       bool            isPieceData,
+                       uint64_t        now);
 
 /******
 *******
 ******/
 
-void    tr_bandwidthSetParent       (tr_bandwidth        * bandwidth,
-                                        tr_bandwidth        * parent);
+void tr_bandwidthSetParent (tr_bandwidth  * bandwidth,
+                            tr_bandwidth  * parent);
 
 /**
  * Almost all the time we do want to honor a parents' bandwidth cap, so that
@@ -237,31 +241,33 @@ void    tr_bandwidthSetParent       (tr_bandwidth        * bandwidth,
  * But when we set a torrent's speed mode to TR_SPEEDLIMIT_UNLIMITED, then
  * in that particular case we want to ignore the global speed limit...
  */
-static inline bool tr_bandwidthHonorParentLimits (tr_bandwidth   * bandwidth,
-                                                   tr_direction     direction,
-                                                   bool             isEnabled)
+static inline bool
+tr_bandwidthHonorParentLimits (tr_bandwidth   * bandwidth,
+                               tr_direction     direction,
+                               bool             isEnabled)
 {
-    bool * value = &bandwidth->band[direction].honorParentLimits;
-    const bool didChange = isEnabled != *value;
-    *value = isEnabled;
-    return didChange;
+  bool * value = &bandwidth->band[direction].honorParentLimits;
+  const bool didChange = isEnabled != *value;
+  *value = isEnabled;
+  return didChange;
 }
 
-static inline bool tr_bandwidthAreParentLimitsHonored (const tr_bandwidth  * bandwidth,
-                                                       tr_direction          direction)
+static inline bool
+tr_bandwidthAreParentLimitsHonored (const tr_bandwidth  * bandwidth,
+                                    tr_direction          direction)
 {
-    assert (tr_isBandwidth (bandwidth));
-    assert (tr_isDirection (direction));
+  assert (tr_isBandwidth (bandwidth));
+  assert (tr_isDirection (direction));
 
-    return bandwidth->band[direction].honorParentLimits;
+  return bandwidth->band[direction].honorParentLimits;
 }
 
 /******
 *******
 ******/
 
-void tr_bandwidthSetPeer (tr_bandwidth        * bandwidth,
-                          struct tr_peerIo    * peerIo);
+void tr_bandwidthSetPeer (tr_bandwidth      * bandwidth,
+                          struct tr_peerIo  * peerIo);
 
 /* @} */
 #endif
