@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: magnet.h 13625 2012-12-05 17:29:46Z jordan $
+ * $Id: magnet.h 13667 2012-12-14 04:34:42Z jordan $
  */
 
 #ifndef __TRANSMISSION__
@@ -18,6 +18,7 @@
 #define TR_MAGNET_H 1
 
 #include "transmission.h"
+#include "variant.h"
 
 typedef struct tr_magnet_info
 {
@@ -35,9 +36,9 @@ tr_magnet_info;
 
 tr_magnet_info * tr_magnetParse (const char * uri);
 
-struct tr_benc;
+struct tr_variant;
 
-void tr_magnetCreateMetainfo (const tr_magnet_info *, struct tr_benc *);
+void tr_magnetCreateMetainfo (const tr_magnet_info *, tr_variant *);
 
 void tr_magnetFree (tr_magnet_info * info);
 
