@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: metainfo.h 13632 2012-12-09 01:27:01Z jordan $
+ * $Id: metainfo.h 13667 2012-12-14 04:34:42Z jordan $
  */
 
 #ifndef __TRANSMISSION__
@@ -18,14 +18,13 @@
 #define TR_METAINFO_H 1
 
 #include "transmission.h"
+#include "variant.h"
 
-struct tr_benc;
-
-bool  tr_metainfoParse (const tr_session     * session,
-                        const struct tr_benc * benc,
-                        tr_info              * setmeInfo,
-                        bool                 * setmeHasInfoDict,
-                        int                  * setmeInfoDictLength);
+bool  tr_metainfoParse (const tr_session  * session,
+                        const tr_variant  * variant,
+                        tr_info           * setmeInfo,
+                        bool              * setmeHasInfoDict,
+                        int               * setmeInfoDictLength);
 
 void tr_metainfoRemoveSaved (const tr_session * session,
                              const tr_info    * info);
