@@ -7,15 +7,16 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: stats.c 13625 2012-12-05 17:29:46Z jordan $
+ * $Id: stats.c 13868 2013-01-25 23:34:20Z jordan $
  */
 
 #include "transmission.h"
 #include "session.h"
-#include "bencode.h"
+#include "log.h"
 #include "platform.h" /* tr_sessionGetConfigDir () */
 #include "stats.h"
 #include "utils.h" /* tr_buildPath */
+#include "variant.h"
 
 /***
 ****
@@ -47,18 +48,18 @@ getFilename (const tr_session * session)
 static void
 loadCumulativeStats (const tr_session * session, tr_session_stats * setme)
 {
-  tr_benc top;
+  tr_variant top;
   char * filename;
   bool loaded = false;
 
   filename = getFilename (session);
-  loaded = !tr_bencLoadFile (&top, TR_FMT_JSON, filename);
+  loaded = !tr_variantFromFile (&top, TR_VARIANT_FMT_JSON, filename);
   tr_free (filename);
 
   if (!loaded)
     {
       filename = getOldFilename (session);
-      loaded = !tr_bencLoadFile (&top, TR_FMT_BENC, filename);
+      loaded = !tr_variantFromFile (&top, TR_VARIANT_FMT_BENC, filename);
       tr_free (filename);
     }
 
@@ -66,18 +67,18 @@ loadCumulativeStats (const tr_session * session, tr_session_stats * setme)
     {
       int64_t i;
 
-      if (tr_bencDictFindInt (&top, "downloaded-bytes", &i))
+      if (tr_variantDictFindInt (&top, TR_KEY_downloaded_bytes, &i))
         setme->downloadedBytes = (uint64_t) i;
-      if (tr_bencDictFindInt (&top, "files-added", &i))
+      if (tr_variantDictFindInt (&top, TR_KEY_files_added, &i))
         setme->filesAdded = (uint64_t) i;
-      if (tr_bencDictFindInt (&top, "seconds-active", &i))
+      if (tr_variantDictFindInt (&top, TR_KEY_seconds_active, &i))
         setme->secondsActive = (uint64_t) i;
-      if (tr_bencDictFindInt (&top, "session-count", &i))
+      if (tr_variantDictFindInt (&top, TR_KEY_session_count, &i))
         setme->sessionCount = (uint64_t) i;
-      if (tr_bencDictFindInt (&top, "uploaded-bytes", &i))
+      if (tr_variantDictFindInt (&top, TR_KEY_uploaded_bytes, &i))
         setme->uploadedBytes = (uint64_t) i;
 
-      tr_bencFree (&top);
+      tr_variantFree (&top);
     }
 }
 
@@ -85,21 +86,21 @@ static void
 saveCumulativeStats (const tr_session * session, const tr_session_stats * s)
 {
   char * filename;
-  tr_benc top;
+  tr_variant top;
 
-  tr_bencInitDict (&top, 5);
-  tr_bencDictAddInt (&top, "downloaded-bytes", s->downloadedBytes);
-  tr_bencDictAddInt (&top, "files-added",      s->filesAdded);
-  tr_bencDictAddInt (&top, "seconds-active",   s->secondsActive);
-  tr_bencDictAddInt (&top, "session-count",    s->sessionCount);
-  tr_bencDictAddInt (&top, "uploaded-bytes",   s->uploadedBytes);
+  tr_variantInitDict (&top, 5);
+  tr_variantDictAddInt (&top, TR_KEY_downloaded_bytes, s->downloadedBytes);
+  tr_variantDictAddInt (&top, TR_KEY_files_added,      s->filesAdded);
+  tr_variantDictAddInt (&top, TR_KEY_seconds_active,   s->secondsActive);
+  tr_variantDictAddInt (&top, TR_KEY_session_count,    s->sessionCount);
+  tr_variantDictAddInt (&top, TR_KEY_uploaded_bytes,   s->uploadedBytes);
 
   filename = getFilename (session);
-  tr_deepLog (__FILE__, __LINE__, NULL, "Saving stats to \"%s\"", filename);
-  tr_bencToFile (&top, TR_FMT_JSON, filename);
+  tr_logAddDeep (__FILE__, __LINE__, NULL, "Saving stats to \"%s\"", filename);
+  tr_variantToFile (&top, TR_VARIANT_FMT_JSON, filename);
 
   tr_free (filename);
-  tr_bencFree (&top);
+  tr_variantFree (&top);
 }
 
 /***
