@@ -27,16 +27,12 @@ THE SOFTWARE.
 #ifndef _TR_LPD_H
 #define _TR_LPD_H
 
-/* $Id: tr-lpd.h 11599 2010-12-27 19:18:17Z charles $ */
+/* $Id: tr-lpd.h 13625 2012-12-05 17:29:46Z jordan $ */
 
-int tr_lpdInit( tr_session*, tr_address* );
-void tr_lpdUninit( tr_session* );
-
-tr_bool tr_lpdEnabled( const tr_session* );
-
-tr_bool tr_lpdSendAnnounce( const tr_torrent* );
-
-int tr_lpdAnnounceMore( const time_t, const int );
+int  tr_lpdInit (tr_session*, tr_address*);
+void tr_lpdUninit (tr_session*);
+bool tr_lpdEnabled (const tr_session*);
+bool tr_lpdSendAnnounce (const tr_torrent*);
 
 /**
 * @defgroup Preproc Helper macros
@@ -44,15 +40,15 @@ int tr_lpdAnnounceMore( const time_t, const int );
 *
 * @def lengthof
 * @brief returns the static length of a C array type
-* @note A lower case macro name is tolerable here since this definition of lengthof()
+* @note A lower case macro name is tolerable here since this definition of lengthof ()
 * is intimately related to sizeof semantics.
 * Meaningful return values are only guaranteed for true array types. */
-#define lengthof( arr ) ( sizeof( *(arr) ) > 0 ? sizeof( arr ) / sizeof( *(arr) ) : 0 )
+#define lengthof(arr)(sizeof (* (arr)) > 0 ? sizeof (arr) / sizeof (* (arr)) : 0)
 
 /**
 * @def STATIC_ASSERT
 * @brief This helper allows to perform static checks at compile time */
-#define STATIC_ASSERT( x ) { const char static_check[( (x) ? 1 : -1 )] UNUSED; }
+#define STATIC_ASSERT(x) { const char static_check[ ((x) ? 1 : -1)] UNUSED; }
 
 /**
 * @} */
