@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: FileOutlineController.m 13169 2012-01-18 01:40:34Z livings124 $
+ * $Id: FileOutlineController.m 13986 2013-02-08 13:02:16Z livings124 $
  *
  * Copyright (c) 2008-2012 Transmission authors and contributors
  *
@@ -24,9 +24,10 @@
 
 #import "FileOutlineController.h"
 #import "Torrent.h"
+#import "FileListNode.h"
 #import "FileOutlineView.h"
 #import "FilePriorityCell.h"
-#import "FileListNode.h"
+#import "FileRenameSheetController.h"
 #import "NSApplicationAdditions.h"
 #import "NSMutableArrayAdditions.h"
 #import "NSStringAdditions.h"
@@ -378,6 +379,20 @@ typedef enum
     [fOutline setNeedsDisplay: YES];
 }
 
+- (void) checkAll
+{
+    NSIndexSet * indexSet = [NSIndexSet indexSetWithIndexesInRange: NSMakeRange(0, [fTorrent fileCount])];
+    [fTorrent setFileCheckState: NSOnState forIndexes: indexSet];
+    [fOutline setNeedsDisplay: YES];
+}
+
+- (void) uncheckAll
+{
+    NSIndexSet * indexSet = [NSIndexSet indexSetWithIndexesInRange: NSMakeRange(0, [fTorrent fileCount])];
+    [fTorrent setFileCheckState: NSOffState forIndexes: indexSet];
+    [fOutline setNeedsDisplay: YES];
+}
+
 - (void) setPriority: (id) sender
 {
     tr_priority_t priority;
@@ -417,6 +432,33 @@ typedef enum
         [[NSWorkspace sharedWorkspace] activateFileViewerSelectingURLs: paths];
 }
 
+- (void) renameSelected: (id) sender
+{
+    NSIndexSet * indexes = [fOutline selectedRowIndexes];
+    NSAssert([indexes count] == 1, @"1 file needs to be selected to rename, but %ld are selected", [indexes count]);
+    
+    FileListNode * node = [fOutline itemAtRow: [indexes firstIndex]];
+    Torrent * torrent = [node torrent];
+    if (![torrent isFolder])
+    {
+        [FileRenameSheetController presentSheetForTorrent: torrent modalForWindow: [fOutline window] completionHandler: ^(BOOL didRename) {
+            if (didRename)
+            {
+                [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateQueue" object: self];
+                [[NSNotificationCenter defaultCenter] postNotificationName: @"ResetInspector" object: self userInfo: @{ @"Torrent" : torrent }];
+            }
+        }];
+    }
+    else
+    {
+        [FileRenameSheetController presentSheetForFileListNode: node modalForWindow: [fOutline window] completionHandler: ^(BOOL didRename) {
+            #warning instead of calling reset inspector, just resort?
+            if (didRename)
+                [[NSNotificationCenter defaultCenter] postNotificationName: @"ResetInspector" object: self userInfo: @{ @"Torrent" : torrent }];
+        }];
+    }
+}
+
 #warning make real view controller (Leopard-only) so that Command-R will work
 - (BOOL) validateMenuItem: (NSMenuItem *) menuItem
 {
@@ -504,6 +546,11 @@ typedef enum
         return canChange;
     }
     
+    if (action == @selector(renameSelected:))
+    {
+        return [fOutline numberOfSelectedRows] == 1;
+    }
+    
     return YES;
 }
 
@@ -517,7 +564,7 @@ typedef enum
     
     //check and uncheck
     NSMenuItem * item = [[NSMenuItem alloc] initWithTitle: NSLocalizedString(@"Check Selected", "File Outline -> Menu")
-                            action: @selector(setCheck:) keyEquivalent: @""];
+            action: @selector(setCheck:) keyEquivalent: @""];
     [item setTarget: self];
     [item setTag: FILE_CHECK_TAG];
     [menu addItem: item];
@@ -550,7 +597,7 @@ typedef enum
             action: @selector(setPriority:) keyEquivalent: @""];
     [item setTarget: self];
     [item setTag: FILE_PRIORITY_HIGH_TAG];
-    [item setImage: [NSImage imageNamed: @"PriorityHighTemplate.png"]];
+    [item setImage: [NSImage imageNamed: @"PriorityHighTemplate"]];
     [priorityMenu addItem: item];
     [item release];
     
@@ -558,7 +605,7 @@ typedef enum
             action: @selector(setPriority:) keyEquivalent: @""];
     [item setTarget: self];
     [item setTag: FILE_PRIORITY_NORMAL_TAG];
-    [item setImage: [NSImage imageNamed: @"PriorityNormalTemplate.png"]];
+    [item setImage: [NSImage imageNamed: @"PriorityNormalTemplate"]];
     [priorityMenu addItem: item];
     [item release];
     
@@ -566,7 +613,7 @@ typedef enum
             action: @selector(setPriority:) keyEquivalent: @""];
     [item setTarget: self];
     [item setTag: FILE_PRIORITY_LOW_TAG];
-    [item setImage: [NSImage imageNamed: @"PriorityLowTemplate.png"]];
+    [item setImage: [NSImage imageNamed: @"PriorityLowTemplate"]];
     [priorityMenu addItem: item];
     [item release];
     
@@ -576,7 +623,16 @@ typedef enum
     
     //reveal in finder
     item = [[NSMenuItem alloc] initWithTitle: NSLocalizedString(@"Show in Finder", "File Outline -> Menu")
-            action: @selector(revealFile:) keyEquivalent: @""];
+                                      action: @selector(revealFile:) keyEquivalent: @""];
+    [item setTarget: self];
+    [menu addItem: item];
+    [item release];
+    
+    [menu addItem: [NSMenuItem separatorItem]];
+    
+    //rename
+    item = [[NSMenuItem alloc] initWithTitle: [NSLocalizedString(@"Rename File", "File Outline -> Menu") stringByAppendingEllipsis]
+                                                   action: @selector(renameSelected:) keyEquivalent: @""];
     [item setTarget: self];
     [menu addItem: item];
     [item release];
