@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: InfoActivityViewController.m 13660 2012-12-13 13:38:58Z livings124 $
+ * $Id: InfoActivityViewController.m 14052 2013-03-12 03:33:54Z livings124 $
  *
  * Copyright (c) 2010-2012 Transmission authors and contributors
  *
@@ -37,8 +37,6 @@
 
 - (void) setupInfo;
 
-- (void) updatePiecesView;
-
 @end
 
 @implementation InfoActivityViewController
@@ -55,9 +53,7 @@
 
 - (void) awakeFromNib
 {
-    [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(updatePiecesView) name: @"UpdatePiecesView" object: nil];
-    
-    /*[fTransferSectionLabel sizeToFit];
+    [fTransferSectionLabel sizeToFit];
     [fDatesSectionLabel sizeToFit];
     [fTimeSectionLabel sizeToFit];
     
@@ -94,7 +90,12 @@
         frame.origin.x += widthIncrease;
         frame.size.width -= widthIncrease;
         [field setFrame: frame];
-    }*/
+    }
+    
+    //set the click action of the pieces view
+    #warning after 2.8 just hook this up in the xib
+    [fPiecesView setAction:@selector(updatePiecesView:)];
+    [fPiecesView setTarget:self];
 }
 
 - (void) dealloc
@@ -200,7 +201,18 @@
 {
     const BOOL availability = [sender selectedSegment] == PIECES_CONTROL_AVAILABLE;
     [[NSUserDefaults standardUserDefaults] setBool: availability forKey: @"PiecesViewShowAvailability"];
-    [self updatePiecesView];
+    [self updatePiecesView:nil];
+}
+
+
+- (void) updatePiecesView: (id) sender
+{
+    const BOOL piecesAvailableSegment = [[NSUserDefaults standardUserDefaults] boolForKey: @"PiecesViewShowAvailability"];
+    
+    [fPiecesControl setSelected: piecesAvailableSegment forSegment: PIECES_CONTROL_AVAILABLE];
+    [fPiecesControl setSelected: !piecesAvailableSegment forSegment: PIECES_CONTROL_PROGRESS];
+    
+    [fPiecesView updateView];
 }
 
 - (void) clearView
@@ -259,14 +271,4 @@
     fSet = YES;
 }
 
-- (void) updatePiecesView
-{
-    const BOOL piecesAvailableSegment = [[NSUserDefaults standardUserDefaults] boolForKey: @"PiecesViewShowAvailability"];
-    
-    [fPiecesControl setSelected: piecesAvailableSegment forSegment: PIECES_CONTROL_AVAILABLE];
-    [fPiecesControl setSelected: !piecesAvailableSegment forSegment: PIECES_CONTROL_PROGRESS];
-    
-    [fPiecesView updateView];
-}
-
 @end
