@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: PiecesView.m 13162 2012-01-14 17:12:04Z livings124 $
+ * $Id: PiecesView.m 14050 2013-03-12 02:56:35Z livings124 $
  *
  * Copyright (c) 2006-2012 Transmission authors and contributors
  *
@@ -216,7 +216,7 @@ enum
         const BOOL availability = ![[NSUserDefaults standardUserDefaults] boolForKey: @"PiecesViewShowAvailability"];
         [[NSUserDefaults standardUserDefaults] setBool: availability forKey: @"PiecesViewShowAvailability"];
         
-        [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdatePiecesView" object: self];
+        [self sendAction:[self action] to:[self target]];
     }
     
     [super mouseDown: event];
