@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: PrefsController.m 13492 2012-09-10 02:37:29Z livings124 $
+ * $Id: PrefsController.m 13804 2013-01-19 05:03:00Z livings124 $
  *
  * Copyright (c) 2005-2012 Transmission authors and contributors
  *
@@ -30,7 +30,7 @@
 #import "BonjourController.h"
 #import "NSApplicationAdditions.h"
 #import "NSStringAdditions.h"
-#import "UKKQueue.h"
+#import "VDKQueue.h"
 
 #import "transmission.h"
 #import "utils.h"
@@ -108,7 +108,7 @@
         //set auto import
         NSString * autoPath;
         if ([fDefaults boolForKey: @"AutoImport"] && (autoPath = [fDefaults stringForKey: @"AutoImportDirectory"]))
-            [[UKKQueue sharedFileWatcher] addPath: [autoPath stringByExpandingTildeInPath]];
+            [[(Controller *)[NSApp delegate] fileWatcherQueue] addPath: [autoPath stringByExpandingTildeInPath] notifyingAbout: VDKQueueNotifyAboutWrite];
         
         //set blocklist scheduler
         [[BlocklistScheduler scheduler] updateSchedule];
@@ -924,11 +924,14 @@
     NSString * path;
     if ((path = [fDefaults stringForKey: @"AutoImportDirectory"]))
     {
-        path = [path stringByExpandingTildeInPath];
+        VDKQueue * watcherQueue = [(Controller *)[NSApp delegate] fileWatcherQueue];
         if ([fDefaults boolForKey: @"AutoImport"])
-            [[UKKQueue sharedFileWatcher] addPath: path];
+        {
+            path = [path stringByExpandingTildeInPath];
+            [watcherQueue addPath: path notifyingAbout: VDKQueueNotifyAboutWrite];
+        }
         else
-            [[UKKQueue sharedFileWatcher] removePathFromQueue: path];
+            [watcherQueue removeAllPaths];
         
         [[NSNotificationCenter defaultCenter] postNotificationName: @"AutoImportSettingChange" object: self];
     }
@@ -947,21 +950,23 @@
     [panel setCanCreateDirectories: YES];
 
     [panel beginSheetModalForWindow: [self window] completionHandler: ^(NSInteger result) {
-        NSString * path = [fDefaults stringForKey: @"AutoImportDirectory"];
         if (result == NSFileHandlingPanelOKButton)
         {
-            UKKQueue * sharedQueue = [UKKQueue sharedFileWatcher];
-            if (path)
-                [sharedQueue removePathFromQueue: [path stringByExpandingTildeInPath]];
+            VDKQueue * watcherQueue = [(Controller *)[NSApp delegate] fileWatcherQueue];
+            [watcherQueue removeAllPaths];
             
-            path = [[[panel URLs] objectAtIndex: 0] path];
+            NSString * path = [[[panel URLs] objectAtIndex: 0] path];
             [fDefaults setObject: path forKey: @"AutoImportDirectory"];
-            [sharedQueue addPath: [path stringByExpandingTildeInPath]];
+            [watcherQueue addPath: [path stringByExpandingTildeInPath] notifyingAbout: VDKQueueNotifyAboutWrite];
             
             [[NSNotificationCenter defaultCenter] postNotificationName: @"AutoImportSettingChange" object: self];
         }
-        else if (!path)
-            [fDefaults setBool: NO forKey: @"AutoImport"];
+        else
+        {
+            NSString * path = [fDefaults stringForKey: @"AutoImportDirectory"];
+            if (!path)
+                [fDefaults setBool: NO forKey: @"AutoImport"];
+        }
         
         [fImportFolderPopUp selectItemAtIndex: 0];
     }];
