@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2010 by Juliusz Chroboczek
+Copyright (c) 2009-2011 by Juliusz Chroboczek
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -39,10 +39,17 @@ THE SOFTWARE.
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/time.h>
+
+#ifndef WIN32
 #include <arpa/inet.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
+#else
+#include <w32api.h>
+#define WINVER WindowsXP
+#include <ws2tcpip.h>
+#endif
 
 #include "dht.h"
 
@@ -56,6 +63,47 @@ THE SOFTWARE.
 #define MSG_CONFIRM 0
 #endif
 
+#ifdef WIN32
+
+#define EAFNOSUPPORT WSAEAFNOSUPPORT
+static int
+set_nonblocking(int fd, int nonblocking)
+{
+    int rc;
+
+    unsigned long mode = !!nonblocking;
+    rc = ioctlsocket(fd, FIONBIO, &mode);
+    if(rc != 0)
+        errno = WSAGetLastError();
+    return (rc == 0 ? 0 : -1);
+}
+
+static int
+random(void)
+{
+    return rand();
+}
+extern const char *inet_ntop(int, const void *, char *, socklen_t);
+
+#else
+
+static int
+set_nonblocking(int fd, int nonblocking)
+{
+    int rc;
+    rc = fcntl(fd, F_GETFL, 0);
+    if(rc < 0)
+        return -1;
+
+    rc = fcntl(fd, F_SETFL, nonblocking?(rc | O_NONBLOCK):(rc & ~O_NONBLOCK));
+    if(rc < 0)
+        return -1;
+
+    return 0;
+}
+
+#endif
+
 /* We set sin_family to 0 to mark unused slots. */
 #if AF_INET == 0 || AF_INET6 == 0
 #error You lose
@@ -164,34 +212,36 @@ struct storage {
     struct storage *next;
 };
 
-static int send_ping(struct sockaddr *sa, int salen,
+static void flush_search_node(struct search_node *n, struct search *sr);
+
+static int send_ping(const struct sockaddr *sa, int salen,
                      const unsigned char *tid, int tid_len);
-static int send_pong(struct sockaddr *sa, int salen,
+static int send_pong(const struct sockaddr *sa, int salen,
                      const unsigned char *tid, int tid_len);
-static int send_find_node(struct sockaddr *sa, int salen,
+static int send_find_node(const struct sockaddr *sa, int salen,
                           const unsigned char *tid, int tid_len,
                           const unsigned char *target, int want, int confirm);
-static int send_nodes_peers(struct sockaddr *sa, int salen,
+static int send_nodes_peers(const struct sockaddr *sa, int salen,
                             const unsigned char *tid, int tid_len,
                             const unsigned char *nodes, int nodes_len,
                             const unsigned char *nodes6, int nodes6_len,
                             int af, struct storage *st,
                             const unsigned char *token, int token_len);
-static int send_closest_nodes(struct sockaddr *sa, int salen,
+static int send_closest_nodes(const struct sockaddr *sa, int salen,
                               const unsigned char *tid, int tid_len,
                               const unsigned char *id, int want,
                               int af, struct storage *st,
                               const unsigned char *token, int token_len);
-static int send_get_peers(struct sockaddr *sa, int salen,
+static int send_get_peers(const struct sockaddr *sa, int salen,
                           unsigned char *tid, int tid_len,
                           unsigned char *infohash, int want, int confirm);
-static int send_announce_peer(struct sockaddr *sa, int salen,
+static int send_announce_peer(const struct sockaddr *sa, int salen,
                               unsigned char *tid, int tid_len,
                               unsigned char *infohas, unsigned short port,
                               unsigned char *token, int token_len, int confirm);
-static int send_peer_announced(struct sockaddr *sa, int salen,
+static int send_peer_announced(const struct sockaddr *sa, int salen,
                                unsigned char *tid, int tid_len);
-static int send_error(struct sockaddr *sa, int salen,
+static int send_error(const struct sockaddr *sa, int salen,
                       unsigned char *tid, int tid_len,
                       int code, const char *message);
 
@@ -262,7 +312,7 @@ static struct timeval now;
 static time_t mybucket_grow_time, mybucket6_grow_time;
 static time_t expire_stuff_time;
 
-#define MAX_TOKEN_BUCKET_TOKENS 40
+#define MAX_TOKEN_BUCKET_TOKENS 400
 static time_t token_bucket_time;
 static int token_bucket_tokens;
 
@@ -301,7 +351,7 @@ print_hex(FILE *f, const unsigned char *buf, int buflen)
 }
 
 static int
-is_martian(struct sockaddr *sa)
+is_martian(const struct sockaddr *sa)
 {
     switch(sa->sa_family) {
     case AF_INET: {
@@ -331,7 +381,7 @@ is_martian(struct sockaddr *sa)
 /* Forget about the ``XOR-metric''.  An id is just a path from the
    root of the tree, so bits are numbered from the start. */
 
-static inline int
+static int
 id_cmp(const unsigned char *restrict id1, const unsigned char *restrict id2)
 {
     /* Memcmp is guaranteed to perform an unsigned comparison. */
@@ -588,6 +638,68 @@ send_cached_ping(struct bucket *b)
     return rc;
 }
 
+/* Called whenever we send a request to a node, increases the ping count
+   and, if that reaches 3, sends a ping to a new candidate. */
+static void
+pinged(struct node *n, struct bucket *b)
+{
+    n->pinged++;
+    n->pinged_time = now.tv_sec;
+    if(n->pinged >= 3)
+        send_cached_ping(b ? b : find_bucket(n->id, n->ss.ss_family));
+}
+
+/* The internal blacklist is an LRU cache of nodes that have sent
+   incorrect messages. */
+static void
+blacklist_node(const unsigned char *id, const struct sockaddr *sa, int salen)
+{
+    int i;
+
+    debugf("Blacklisting broken node.\n");
+
+    if(id) {
+        struct node *n;
+        struct search *sr;
+        /* Make the node easy to discard. */
+        n = find_node(id, sa->sa_family);
+        if(n) {
+            n->pinged = 3;
+            pinged(n, NULL);
+        }
+        /* Discard it from any searches in progress. */
+        sr = searches;
+        while(sr) {
+            for(i = 0; i < sr->numnodes; i++)
+                if(id_cmp(sr->nodes[i].id, id) == 0)
+                    flush_search_node(&sr->nodes[i], sr);
+            sr = sr->next;
+        }
+    }
+    /* And make sure we don't hear from it again. */
+    memcpy(&blacklist[next_blacklisted], sa, salen);
+    next_blacklisted = (next_blacklisted + 1) % DHT_MAX_BLACKLISTED;
+}
+
+static int
+node_blacklisted(const struct sockaddr *sa, int salen)
+{
+    int i;
+
+    if((unsigned)salen > sizeof(struct sockaddr_storage))
+        abort();
+
+    if(dht_blacklisted(sa, salen))
+        return 1;
+
+    for(i = 0; i < DHT_MAX_BLACKLISTED; i++) {
+        if(memcmp(&blacklist[i], sa, salen) == 0)
+            return 1;
+    }
+
+    return 0;
+}
+
 /* Split a bucket into two equal parts. */
 static struct bucket *
 split_bucket(struct bucket *b)
@@ -626,20 +738,11 @@ split_bucket(struct bucket *b)
     return b;
 }
 
-/* Called whenever we send a request to a node. */
-static void
-pinged(struct node *n, struct bucket *b)
-{
-    n->pinged++;
-    n->pinged_time = now.tv_sec;
-    if(n->pinged >= 3)
-        send_cached_ping(b ? b : find_bucket(n->id, n->ss.ss_family));
-}
-
 /* We just learnt about a node, not necessarily a new one.  Confirm is 1 if
    the node sent a message, 2 if it sent us a reply. */
 static struct node *
-new_node(const unsigned char *id, struct sockaddr *sa, int salen, int confirm)
+new_node(const unsigned char *id, const struct sockaddr *sa, int salen,
+         int confirm)
 {
     struct bucket *b = find_bucket(id, sa->sa_family);
     struct node *n;
@@ -651,7 +754,7 @@ new_node(const unsigned char *id, struct sockaddr *sa, int salen, int confirm)
     if(id_cmp(id, myid) == 0)
         return NULL;
 
-    if(is_martian(sa))
+    if(is_martian(sa) || node_blacklisted(sa, salen))
         return NULL;
 
     mybucket = in_bucket(myid, b);
@@ -831,7 +934,7 @@ find_search(unsigned short tid, int af)
 
 static int
 insert_search_node(unsigned char *id,
-                   struct sockaddr *sa, int salen,
+                   const struct sockaddr *sa, int salen,
                    struct search *sr, int replied,
                    unsigned char *token, int token_len)
 {
@@ -1172,12 +1275,24 @@ find_storage(const unsigned char *id)
 }
 
 static int
-storage_store(const unsigned char *id, struct sockaddr *sa)
+storage_store(const unsigned char *id,
+              const struct sockaddr *sa, unsigned short port)
 {
     int i, len;
-    struct storage *st = storage;
+    struct storage *st;
     unsigned char *ip;
-    unsigned short port;
+
+    if(sa->sa_family == AF_INET) {
+        struct sockaddr_in *sin = (struct sockaddr_in*)sa;
+        ip = (unsigned char*)&sin->sin_addr;
+        len = 4;
+    } else if(sa->sa_family == AF_INET6) {
+        struct sockaddr_in6 *sin6 = (struct sockaddr_in6*)sa;
+        ip = (unsigned char*)&sin6->sin6_addr;
+        len = 16;
+    } else {
+        return -1;
+    }
 
     st = find_storage(id);
 
@@ -1192,18 +1307,6 @@ storage_store(const unsigned char *id, struct sockaddr *sa)
         numstorage++;
     }
 
-    if(sa->sa_family == AF_INET) {
-        struct sockaddr_in *sin = (struct sockaddr_in*)sa;
-        ip = (unsigned char*)&sin->sin_addr;
-        len = 4;
-        port = ntohs(sin->sin_port);
-    } else if(sa->sa_family == AF_INET6) {
-        struct sockaddr_in6 *sin6 = (struct sockaddr_in6*)sa;
-        ip = (unsigned char*)&sin6->sin6_addr;
-        len = 16;
-        port = ntohs(sin6->sin6_port);
-    }
-
     for(i = 0; i < st->numpeers; i++) {
         if(st->peers[i].port == port && st->peers[i].len == len &&
            memcmp(st->peers[i].ip, ip, len) == 0)
@@ -1279,37 +1382,6 @@ expire_storage(void)
     return 1;
 }
 
-/* We've just found out that a node is buggy. */
-static void
-broken_node(const unsigned char *id, struct sockaddr *sa, int salen)
-{
-    int i;
-
-    debugf("Blacklisting broken node.\n");
-
-    if(id) {
-        struct node *n;
-        struct search *sr;
-        /* Make the node easy to discard. */
-        n = find_node(id, sa->sa_family);
-        if(n) {
-            n->pinged = 3;
-            pinged(n, NULL);
-        }
-        /* Discard it from any searches in progress. */
-        sr = searches;
-        while(sr) {
-            for(i = 0; i < sr->numnodes; i++)
-                if(id_cmp(sr->nodes[i].id, id) == 0)
-                    flush_search_node(&sr->nodes[i], sr);
-            sr = sr->next;
-        }
-    }
-    /* And make sure we don't hear from it again. */
-    memcpy(&blacklist[next_blacklisted], sa, salen);
-    next_blacklisted = (next_blacklisted + 1) % DHT_MAX_BLACKLISTED;
-}
-
 static int
 rotate_secrets(void)
 {
@@ -1331,7 +1403,7 @@ rotate_secrets(void)
 #endif
 
 static void
-make_token(struct sockaddr *sa, int old, unsigned char *token_return)
+make_token(const struct sockaddr *sa, int old, unsigned char *token_return)
 {
     void *ip;
     int iplen;
@@ -1356,7 +1428,8 @@ make_token(struct sockaddr *sa, int old, unsigned char *token_return)
              ip, iplen, (unsigned char*)&port, 2);
 }
 static int
-token_match(unsigned char *token, int token_len, struct sockaddr *sa)
+token_match(const unsigned char *token, int token_len,
+            const struct sockaddr *sa)
 {
     unsigned char t[TOKEN_SIZE];
     if(token_len != TOKEN_SIZE)
@@ -1548,11 +1621,7 @@ dht_init(int s, int s6, const unsigned char *id, const unsigned char *v)
             return -1;
         buckets->af = AF_INET;
 
-        rc = fcntl(s, F_GETFL, 0);
-        if(rc < 0)
-            goto fail;
-
-        rc = fcntl(s, F_SETFL, (rc | O_NONBLOCK));
+        rc = set_nonblocking(s, 1);
         if(rc < 0)
             goto fail;
     }
@@ -1563,11 +1632,7 @@ dht_init(int s, int s6, const unsigned char *id, const unsigned char *v)
             return -1;
         buckets6->af = AF_INET6;
 
-        rc = fcntl(s6, F_GETFL, 0);
-        if(rc < 0)
-            goto fail;
-
-        rc = fcntl(s6, F_SETFL, (rc | O_NONBLOCK));
+        rc = set_nonblocking(s6, 1);
         if(rc < 0)
             goto fail;
     }
@@ -1615,15 +1680,15 @@ dht_init(int s, int s6, const unsigned char *id, const unsigned char *v)
 }
 
 int
-dht_uninit(int dofree)
+dht_uninit()
 {
-    if(dht_socket < 0) {
+    if(dht_socket < 0 && dht_socket6 < 0) {
         errno = EINVAL;
         return -1;
     }
 
-    if(!dofree)
-        return 1;
+    dht_socket = -1;
+    dht_socket6 = -1;
 
     while(buckets) {
         struct bucket *b = buckets;
@@ -1636,6 +1701,17 @@ dht_uninit(int dofree)
         free(b);
     }
 
+    while(buckets6) {
+        struct bucket *b = buckets6;
+        buckets6 = b->next;
+        while(b->nodes) {
+            struct node *n = b->nodes;
+            b->nodes = n->next;
+            free(n);
+        }
+        free(b);
+    }
+
     while(storage) {
         struct storage *st = storage;
         storage = storage->next;
@@ -1659,7 +1735,7 @@ token_bucket(void)
 {
     if(token_bucket_tokens == 0) {
         token_bucket_tokens = MIN(MAX_TOKEN_BUCKET_TOKENS,
-                                  4 * (now.tv_sec - token_bucket_time));
+                                  100 * (now.tv_sec - token_bucket_time));
         token_bucket_time = now.tv_sec;
     }
 
@@ -1788,68 +1864,40 @@ bucket_maintenance(int af)
 }
 
 int
-dht_periodic(int available, time_t *tosleep,
+dht_periodic(const void *buf, size_t buflen,
+             const struct sockaddr *from, int fromlen,
+             time_t *tosleep,
              dht_callback *callback, void *closure)
 {
-    int i;
-
     gettimeofday(&now, NULL);
 
-    if(available) {
-        int rc, message;
+    if(buflen > 0) {
+        int message;
         unsigned char tid[16], id[20], info_hash[20], target[20];
-        unsigned char buf[1536], nodes[256], nodes6[1024], token[128];
+        unsigned char nodes[256], nodes6[1024], token[128];
         int tid_len = 16, token_len = 128;
         int nodes_len = 256, nodes6_len = 1024;
         unsigned short port;
         unsigned char values[2048], values6[2048];
         int values_len = 2048, values6_len = 2048;
-        int want, want4, want6;
-        struct sockaddr_storage source_storage;
-        struct sockaddr *source = (struct sockaddr*)&source_storage;
-        socklen_t sourcelen = sizeof(source_storage);
+        int want;
         unsigned short ttid;
 
-        rc = -1;
-        if(dht_socket >= 0) {
-            rc = recvfrom(dht_socket, buf, 1536, 0, source, &sourcelen);
-            if(rc < 0 && errno != EAGAIN) {
-                    return rc;
-            }
-        }
-        if(dht_socket6 >= 0 && rc < 0) {
-            rc = recvfrom(dht_socket6, buf, 1536, 0,
-                          source, &sourcelen);
-            if(rc < 0 && errno != EAGAIN) {
-                    return rc;
-            }
-        }
-
-        if(rc < 0 || sourcelen > sizeof(struct sockaddr_storage))
+        if(is_martian(from))
             goto dontread;
 
-        if(is_martian(source))
-            goto dontread;
-
-        for(i = 0; i < DHT_MAX_BLACKLISTED; i++) {
-            if(memcmp(&blacklist[i], source, sourcelen) == 0) {
-                debugf("Received packet from blacklisted node.\n");
-                goto dontread;
-            }
-        }
-
-        /* There's a bug in parse_message -- it will happily overflow the
-           buffer if it's not NUL-terminated.  For now, put a NUL at the
-           end of buffers. */
-
-        if(rc < 1536) {
-            buf[rc] = '\0';
-        } else {
-            debugf("Overlong message.\n");
+        if(node_blacklisted(from, fromlen)) {
+            debugf("Received packet from blacklisted node.\n");
             goto dontread;
         }
 
-        message = parse_message(buf, rc, tid, &tid_len, id, info_hash,
+        if(((char*)buf)[buflen] != '\0') {
+            debugf("Unterminated message.\n");
+            errno = EINVAL;
+            return -1;
+        }
+
+        message = parse_message(buf, buflen, tid, &tid_len, id, info_hash,
                                 target, &port, token, &token_len,
                                 nodes, &nodes_len, nodes6, &nodes6_len,
                                 values, &values_len, values6, &values6_len,
@@ -1857,7 +1905,7 @@ dht_periodic(int available, time_t *tosleep,
 
         if(message < 0 || message == ERROR || id_cmp(id, zeroes) == 0) {
             debugf("Unparseable message: ");
-            debug_printable(buf, rc);
+            debug_printable(buf, buflen);
             debugf("\n");
             goto dontread;
         }
@@ -1875,48 +1923,40 @@ dht_periodic(int available, time_t *tosleep,
             }
         }
 
-        if(want > 0) {
-            want4 = (want & WANT4);
-            want6 = (want & WANT6);
-        } else {
-            want4 = source->sa_family == AF_INET;
-            want6 = source->sa_family == AF_INET6;
-        }
-
         switch(message) {
         case REPLY:
             if(tid_len != 4) {
                 debugf("Broken node truncates transaction ids: ");
-                debug_printable(buf, rc);
+                debug_printable(buf, buflen);
                 debugf("\n");
                 /* This is really annoying, as it means that we will
                    time-out all our searches that go through this node.
                    Kill it. */
-                broken_node(id, source, sourcelen);
+                blacklist_node(id, from, fromlen);
                 goto dontread;
             }
             if(tid_match(tid, "pn", NULL)) {
                 debugf("Pong!\n");
-                new_node(id, source, sourcelen, 2);
+                new_node(id, from, fromlen, 2);
             } else if(tid_match(tid, "fn", NULL) ||
                       tid_match(tid, "gp", NULL)) {
                 int gp = 0;
                 struct search *sr = NULL;
                 if(tid_match(tid, "gp", &ttid)) {
                     gp = 1;
-                    sr = find_search(ttid, source->sa_family);
+                    sr = find_search(ttid, from->sa_family);
                 }
                 debugf("Nodes found (%d+%d)%s!\n", nodes_len/26, nodes6_len/38,
                        gp ? " for get_peers" : "");
                 if(nodes_len % 26 != 0 || nodes6_len % 38 != 0) {
                     debugf("Unexpected length for node info!\n");
-                    broken_node(id, source, sourcelen);
+                    blacklist_node(id, from, fromlen);
                 } else if(gp && sr == NULL) {
                     debugf("Unknown search!\n");
-                    new_node(id, source, sourcelen, 1);
+                    new_node(id, from, fromlen, 1);
                 } else {
                     int i;
-                    new_node(id, source, sourcelen, 2);
+                    new_node(id, from, fromlen, 2);
                     for(i = 0; i < nodes_len / 26; i++) {
                         unsigned char *ni = nodes + i * 26;
                         struct sockaddr_in sin;
@@ -1958,7 +1998,7 @@ dht_periodic(int available, time_t *tosleep,
                         search_send_get_peers(sr, NULL);
                 }
                 if(sr) {
-                    insert_search_node(id, source, sourcelen, sr,
+                    insert_search_node(id, from, fromlen, sr,
                                        1, token, token_len);
                     if(values_len > 0 || values6_len > 0) {
                         debugf("Got values (%d+%d)!\n",
@@ -1977,13 +2017,13 @@ dht_periodic(int available, time_t *tosleep,
             } else if(tid_match(tid, "ap", &ttid)) {
                 struct search *sr;
                 debugf("Got reply to announce_peer.\n");
-                sr = find_search(ttid, source->sa_family);
+                sr = find_search(ttid, from->sa_family);
                 if(!sr) {
                     debugf("Unknown search!\n");
-                    new_node(id, source, sourcelen, 1);
+                    new_node(id, from, fromlen, 1);
                 } else {
                     int i;
-                    new_node(id, source, sourcelen, 2);
+                    new_node(id, from, fromlen, 2);
                     for(i = 0; i < sr->numnodes; i++)
                         if(id_cmp(sr->nodes[i].id, id) == 0) {
                             sr->nodes[i].request_time = 0;
@@ -1997,47 +2037,47 @@ dht_periodic(int available, time_t *tosleep,
                 }
             } else {
                 debugf("Unexpected reply: ");
-                debug_printable(buf, rc);
+                debug_printable(buf, buflen);
                 debugf("\n");
             }
             break;
         case PING:
             debugf("Ping (%d)!\n", tid_len);
-            new_node(id, source, sourcelen, 1);
+            new_node(id, from, fromlen, 1);
             debugf("Sending pong.\n");
-            send_pong(source, sourcelen, tid, tid_len);
+            send_pong(from, fromlen, tid, tid_len);
             break;
         case FIND_NODE:
             debugf("Find node!\n");
-            new_node(id, source, sourcelen, 1);
+            new_node(id, from, fromlen, 1);
             debugf("Sending closest nodes (%d).\n", want);
-            send_closest_nodes(source, sourcelen,
+            send_closest_nodes(from, fromlen,
                                tid, tid_len, target, want,
                                0, NULL, NULL, 0);
             break;
         case GET_PEERS:
             debugf("Get_peers!\n");
-            new_node(id, source, sourcelen, 1);
+            new_node(id, from, fromlen, 1);
             if(id_cmp(info_hash, zeroes) == 0) {
                 debugf("Eek!  Got get_peers with no info_hash.\n");
-                send_error(source, sourcelen, tid, tid_len,
+                send_error(from, fromlen, tid, tid_len,
                            203, "Get_peers with no info_hash");
                 break;
             } else {
                 struct storage *st = find_storage(info_hash);
                 unsigned char token[TOKEN_SIZE];
-                make_token(source, 0, token);
+                make_token(from, 0, token);
                 if(st && st->numpeers > 0) {
                      debugf("Sending found%s peers.\n",
-                            source->sa_family == AF_INET6 ? " IPv6" : "");
-                     send_closest_nodes(source, sourcelen,
+                            from->sa_family == AF_INET6 ? " IPv6" : "");
+                     send_closest_nodes(from, fromlen,
                                         tid, tid_len,
                                         info_hash, want,
-                                        source->sa_family, st,
+                                        from->sa_family, st,
                                         token, TOKEN_SIZE);
                 } else {
                     debugf("Sending nodes for get_peers.\n");
-                    send_closest_nodes(source, sourcelen,
+                    send_closest_nodes(from, fromlen,
                                        tid, tid_len, info_hash, want,
                                        0, NULL, token, TOKEN_SIZE);
                 }
@@ -2045,31 +2085,31 @@ dht_periodic(int available, time_t *tosleep,
             break;
         case ANNOUNCE_PEER:
             debugf("Announce peer!\n");
-            new_node(id, source, sourcelen, 1);
+            new_node(id, from, fromlen, 1);
             if(id_cmp(info_hash, zeroes) == 0) {
                 debugf("Announce_peer with no info_hash.\n");
-                send_error(source, sourcelen, tid, tid_len,
+                send_error(from, fromlen, tid, tid_len,
                            203, "Announce_peer with no info_hash");
                 break;
             }
-            if(!token_match(token, token_len, source)) {
+            if(!token_match(token, token_len, from)) {
                 debugf("Incorrect token for announce_peer.\n");
-                send_error(source, sourcelen, tid, tid_len,
+                send_error(from, fromlen, tid, tid_len,
                            203, "Announce_peer with wrong token");
                 break;
             }
             if(port == 0) {
                 debugf("Announce_peer with forbidden port %d.\n", port);
-                send_error(source, sourcelen, tid, tid_len,
+                send_error(from, fromlen, tid, tid_len,
                            203, "Announce_peer with forbidden port number");
                 break;
             }
-            storage_store(info_hash, source);
+            storage_store(info_hash, from, port);
             /* Note that if storage_store failed, we lie to the requestor.
                This is to prevent them from backtracking, and hence
                polluting the DHT. */
             debugf("Sending peer announced.\n");
-            send_peer_announced(source, sourcelen, tid, tid_len);
+            send_peer_announced(from, fromlen, tid, tid_len);
         }
     }
 
@@ -2277,6 +2317,12 @@ dht_send(const void *buf, size_t len, int flags,
     if(salen == 0)
         abort();
 
+    if(node_blacklisted(sa, salen)) {
+        debugf("Attempting to send to blacklisted node.\n");
+        errno = EPERM;
+        return -1;
+    }
+
     if(sa->sa_family == AF_INET)
         s = dht_socket;
     else if(sa->sa_family == AF_INET6)
@@ -2293,7 +2339,7 @@ dht_send(const void *buf, size_t len, int flags,
 }
 
 int
-send_ping(struct sockaddr *sa, int salen,
+send_ping(const struct sockaddr *sa, int salen,
           const unsigned char *tid, int tid_len)
 {
     char buf[512];
@@ -2313,7 +2359,7 @@ send_ping(struct sockaddr *sa, int salen,
 }
 
 int
-send_pong(struct sockaddr *sa, int salen,
+send_pong(const struct sockaddr *sa, int salen,
           const unsigned char *tid, int tid_len)
 {
     char buf[512];
@@ -2332,7 +2378,7 @@ send_pong(struct sockaddr *sa, int salen,
 }
 
 int
-send_find_node(struct sockaddr *sa, int salen,
+send_find_node(const struct sockaddr *sa, int salen,
                const unsigned char *tid, int tid_len,
                const unsigned char *target, int want, int confirm)
 {
@@ -2361,7 +2407,7 @@ send_find_node(struct sockaddr *sa, int salen,
 }
 
 int
-send_nodes_peers(struct sockaddr *sa, int salen,
+send_nodes_peers(const struct sockaddr *sa, int salen,
                  const unsigned char *tid, int tid_len,
                  const unsigned char *nodes, int nodes_len,
                  const unsigned char *nodes6, int nodes6_len,
@@ -2488,7 +2534,7 @@ buffer_closest_nodes(unsigned char *nodes, int numnodes,
 }
 
 int
-send_closest_nodes(struct sockaddr *sa, int salen,
+send_closest_nodes(const struct sockaddr *sa, int salen,
                    const unsigned char *tid, int tid_len,
                    const unsigned char *id, int want,
                    int af, struct storage *st,
@@ -2535,7 +2581,7 @@ send_closest_nodes(struct sockaddr *sa, int salen,
 }
 
 int
-send_get_peers(struct sockaddr *sa, int salen,
+send_get_peers(const struct sockaddr *sa, int salen,
                unsigned char *tid, int tid_len, unsigned char *infohash,
                int want, int confirm)
 {
@@ -2565,7 +2611,7 @@ send_get_peers(struct sockaddr *sa, int salen,
 }
 
 int
-send_announce_peer(struct sockaddr *sa, int salen,
+send_announce_peer(const struct sockaddr *sa, int salen,
                    unsigned char *tid, int tid_len,
                    unsigned char *infohash, unsigned short port,
                    unsigned char *token, int token_len, int confirm)
@@ -2595,7 +2641,7 @@ send_announce_peer(struct sockaddr *sa, int salen,
 }
 
 static int
-send_peer_announced(struct sockaddr *sa, int salen,
+send_peer_announced(const struct sockaddr *sa, int salen,
                     unsigned char *tid, int tid_len)
 {
     char buf[512];
@@ -2616,7 +2662,7 @@ send_peer_announced(struct sockaddr *sa, int salen,
 }
 
 static int
-send_error(struct sockaddr *sa, int salen,
+send_error(const struct sockaddr *sa, int salen,
            unsigned char *tid, int tid_len,
            int code, const char *message)
 {
@@ -2643,10 +2689,20 @@ send_error(struct sockaddr *sa, int salen,
 #undef COPY
 #undef ADD_V
 
-#ifndef HAVE_MEMMEM
+#ifdef HAVE_MEMMEM
+
 static void *
-memmem(const void *haystack, size_t haystacklen,
-       const void *needle, size_t needlelen)
+dht_memmem(const void *haystack, size_t haystacklen,
+           const void *needle, size_t needlelen)
+{
+    return memmem(haystack, haystacklen, needle, needlelen);
+}
+
+#else
+
+static void *
+dht_memmem(const void *haystack, size_t haystacklen,
+           const void *needle, size_t needlelen)
 {
     const char *h = haystack;
     const char *n = needle;
@@ -2662,6 +2718,7 @@ memmem(const void *haystack, size_t haystacklen,
     }
     return NULL;
 }
+
 #endif
 
 static int
@@ -2688,7 +2745,7 @@ parse_message(const unsigned char *buf, int buflen,
     if(((unsigned char*)ptr) + (len) > (buf) + (buflen)) goto overflow;
 
     if(tid_return) {
-        p = memmem(buf, buflen, "1:t", 3);
+        p = dht_memmem(buf, buflen, "1:t", 3);
         if(p) {
             long l;
             char *q;
@@ -2702,7 +2759,7 @@ parse_message(const unsigned char *buf, int buflen,
         }
     }
     if(id_return) {
-        p = memmem(buf, buflen, "2:id20:", 7);
+        p = dht_memmem(buf, buflen, "2:id20:", 7);
         if(p) {
             CHECK(p + 7, 20);
             memcpy(id_return, p + 7, 20);
@@ -2711,7 +2768,7 @@ parse_message(const unsigned char *buf, int buflen,
         }
     }
     if(info_hash_return) {
-        p = memmem(buf, buflen, "9:info_hash20:", 14);
+        p = dht_memmem(buf, buflen, "9:info_hash20:", 14);
         if(p) {
             CHECK(p + 14, 20);
             memcpy(info_hash_return, p + 14, 20);
@@ -2720,7 +2777,7 @@ parse_message(const unsigned char *buf, int buflen,
         }
     }
     if(port_return) {
-        p = memmem(buf, buflen, "porti", 5);
+        p = dht_memmem(buf, buflen, "porti", 5);
         if(p) {
             long l;
             char *q;
@@ -2733,7 +2790,7 @@ parse_message(const unsigned char *buf, int buflen,
             *port_return = 0;
     }
     if(target_return) {
-        p = memmem(buf, buflen, "6:target20:", 11);
+        p = dht_memmem(buf, buflen, "6:target20:", 11);
         if(p) {
             CHECK(p + 11, 20);
             memcpy(target_return, p + 11, 20);
@@ -2742,7 +2799,7 @@ parse_message(const unsigned char *buf, int buflen,
         }
     }
     if(token_return) {
-        p = memmem(buf, buflen, "5:token", 7);
+        p = dht_memmem(buf, buflen, "5:token", 7);
         if(p) {
             long l;
             char *q;
@@ -2758,7 +2815,7 @@ parse_message(const unsigned char *buf, int buflen,
     }
 
     if(nodes_len) {
-        p = memmem(buf, buflen, "5:nodes", 7);
+        p = dht_memmem(buf, buflen, "5:nodes", 7);
         if(p) {
             long l;
             char *q;
@@ -2774,7 +2831,7 @@ parse_message(const unsigned char *buf, int buflen,
     }
 
     if(nodes6_len) {
-        p = memmem(buf, buflen, "6:nodes6", 8);
+        p = dht_memmem(buf, buflen, "6:nodes6", 8);
         if(p) {
             long l;
             char *q;
@@ -2790,7 +2847,7 @@ parse_message(const unsigned char *buf, int buflen,
     }
 
     if(values_len || values6_len) {
-        p = memmem(buf, buflen, "6:valuesl", 9);
+        p = dht_memmem(buf, buflen, "6:valuesl", 9);
         if(p) {
             int i = p - buf + 9;
             int j = 0, j6 = 0;
@@ -2800,21 +2857,19 @@ parse_message(const unsigned char *buf, int buflen,
                 l = strtol((char*)buf + i, &q, 10);
                 if(q && *q == ':' && l > 0) {
                     CHECK(q + 1, l);
+                    i = q + 1 + l - (char*)buf;
                     if(l == 6) {
                         if(j + l > *values_len)
                             continue;
-                        i = q + 1 + l - (char*)buf;
                         memcpy((char*)values_return + j, q + 1, l);
                         j += l;
                     } else if(l == 18) {
                         if(j6 + l > *values6_len)
                             continue;
-                        i = q + 1 + l - (char*)buf;
                         memcpy((char*)values6_return + j6, q + 1, l);
                         j6 += l;
                     } else {
                         debugf("Received weird value -- %d bytes.\n", (int)l);
-                        i = q + 1 + l - (char*)buf;
                     }
                 } else {
                     break;
@@ -2827,13 +2882,15 @@ parse_message(const unsigned char *buf, int buflen,
             if(values6_len)
                 *values6_len = j6;
         } else {
-            *values_len = 0;
-            *values6_len = 0;
+            if(values_len)
+                *values_len = 0;
+            if(values6_len)
+                *values6_len = 0;
         }
     }
 
     if(want_return) {
-        p = memmem(buf, buflen, "4:wantl", 7);
+        p = dht_memmem(buf, buflen, "4:wantl", 7);
         if(p) {
             int i = p - buf + 7;
             *want_return = 0;
@@ -2857,19 +2914,19 @@ parse_message(const unsigned char *buf, int buflen,
 
 #undef CHECK
 
-    if(memmem(buf, buflen, "1:y1:r", 6))
+    if(dht_memmem(buf, buflen, "1:y1:r", 6))
         return REPLY;
-    if(memmem(buf, buflen, "1:y1:e", 6))
+    if(dht_memmem(buf, buflen, "1:y1:e", 6))
         return ERROR;
-    if(!memmem(buf, buflen, "1:y1:q", 6))
+    if(!dht_memmem(buf, buflen, "1:y1:q", 6))
         return -1;
-    if(memmem(buf, buflen, "1:q4:ping", 9))
+    if(dht_memmem(buf, buflen, "1:q4:ping", 9))
         return PING;
-    if(memmem(buf, buflen, "1:q9:find_node", 14))
+    if(dht_memmem(buf, buflen, "1:q9:find_node", 14))
        return FIND_NODE;
-    if(memmem(buf, buflen, "1:q9:get_peers", 14))
+    if(dht_memmem(buf, buflen, "1:q9:get_peers", 14))
         return GET_PEERS;
-    if(memmem(buf, buflen, "1:q13:announce_peer", 19))
+    if(dht_memmem(buf, buflen, "1:q13:announce_peer", 19))
        return ANNOUNCE_PEER;
     return -1;
 
